import inspect
import os
from json import loads as json_loads

from django import template
from django.template import defaultfilters

register = template.Library()

DEBUG_DJANGO_BONUS = os.getenv("DJANGO_BONUS_DEBUG") in [True, "True", "true", "TRUE"]

NAMES_OF_DEFAULT_FILTERS = dir(defaultfilters)
if DEBUG_DJANGO_BONUS:
    print("NAMES_OF_DEFAULT_FILTERS:", NAMES_OF_DEFAULT_FILTERS)


def register_string_method(string_method):
    try:
        if DEBUG_DJANGO_BONUS:
            print("[django-bonus] registering " + string_method)
        register.filter(
            string_method,
            lambda value, arg="[]": getattr(value, string_method)(*json_loads(arg)),
        )
        # if DEBUG_DJANGO_BONUS:
        # print(f"[django-bonus] {string_method} filter is", register.filters[string_method])

        # if string_method not in register.filters:
        # print("[django-bonus] failed to register " + string_method)

    except Exception as e:
        print("[django-bonus] exception while registering " + string_method, e)


for string_method in dir(""):
    if not string_method.startswith("_"):
        if string_method not in NAMES_OF_DEFAULT_FILTERS:
            register_string_method(string_method)



from os import path

from setuptools import setup

this_directory = path.abspath(path.dirname(__file__))
root_directory = path.abspath(path.dirname(this_directory))

with open(path.join(root_directory, "README.md")) as f:
    long_description = f.read()

setup(
    name="django-bonus",
    packages=["django_bonus"],
    package_dir={"django_bonus": "django_bonus"},
    package_data={
        "django_bonus": [
            "__init__.py",
            "templatetags/__init__.py",
            "templatetags/django_bonus.py",
        ]
    },
    version="0.0.0",
    description="Bonus Features for Django: More Template Filters like Replace",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Daniel J. Dufour",
    author_email="daniel.j.dufour@gmail.com",
    url="https://github.com/DanielJDufour/django-bonus",
    download_url="https://github.com/DanielJDufour/django-bonus/tarball/download",
    keywords=["django", "filter", "liquid", "template"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    install_requires=["django"],
)
